@@ -67,5 +67,4 @@ git push
 
 # goreleaser's `--rm-dist' should clear out `dist', but it didn't work for me.
 rm -rf dist
-goreleaser release --rm-dist -f .goreleaser.yml --release-notes <(echo "$message")
-make clean BUILDDIR=.
+goreleaser release --rm-dist -f .goreleaser.yml --release-notes <(echo "$notes")
