@@ -2,10 +2,31 @@
 
 set -e
 
+# SIGTERM-handler
+term_handler() {
+  if [ $pid -ne 0 ]; then
+    kill -SIGTERM "$pid"
+    wait "$pid"
+  fi
+  exit 143; # 128 + 15 -- SIGTERM
+}
+
+trap 'kill ${!}; term_handler' SIGTERM
+
+pid=0
 conf_file=/etc/GeoIP.conf
 database_dir=/usr/share/GeoIP
 flags=
 frequency=$((GEOIPUPDATE_FREQUENCY * 60 * 60))
+
+if ! [ -z "$GEOIPUPDATE_CONF_FILE" ]; then
+  conf_file=$GEOIPUPDATE_CONF_FILE
+fi
+
+if ! [ -z "$GEOIPUPDATE_DB_DIR" ]; then
+  database_dir=$GEOIPUPDATE_DB_DIR
+fi
+
 if [ -z "$GEOIPUPDATE_ACCOUNT_ID" ] || [ -z  "$GEOIPUPDATE_LICENSE_KEY" ] || [ -z "$GEOIPUPDATE_EDITION_IDS" ]; then
     echo "ERROR: You must set the environment variables GEOIPUPDATE_ACCOUNT_ID, GEOIPUPDATE_LICENSE_KEY, and GEOIPUPDATE_EDITION_IDS!"
     exit 1
@@ -47,5 +68,7 @@ while true; do
     fi
 
     echo "# STATE: Sleeping for $GEOIPUPDATE_FREQUENCY hours"
-    sleep "$frequency"
+    sleep "$frequency" &
+    pid=$!
+    wait $!
 done
