@@ -3,6 +3,8 @@ package internal
 
 import (
 	"time"
+
+	"github.com/pkg/errors"
 )
 
 // RetryWithBackoff calls the provided function repeatedly until it succeeds or
@@ -19,6 +21,14 @@ func RetryWithBackoff(
 			return nil
 		}
 
+		underlyingErr := errors.Cause(err)
+		var httpErr HTTPError
+		if errors.As(underlyingErr, &httpErr) &&
+			httpErr.StatusCode >= 400 &&
+			httpErr.StatusCode < 500 {
+			return err
+		}
+
 		currentDuration := time.Since(start)
 
 		waitDuration := 200 * time.Millisecond * (1 << i)
